# Data submission template documentation

**Note:** This Readme file is best displayed in a Markdown capable viewer/editor.

## General information concerning data submissions to PANGAEA

* ==Please follow our Authors Guides (https://wiki.pangaea.de/wiki/Data_submission)==

* Submit data early on, ideally **before** manuscript submission.

* Submit your data here: https://pangaea.de/submit/ 

* Provide detailed metadata, because PANGAEA data publications are generally publications that stand on their own.

* Please complete and submit the campaign (if any), events, parameters and data table included in this template zip file.

* If applicable, attach the cruise report of associated research campaigns to your submission.

### Multiple data tables:
Each submitted data table requires one unique title and abstract. Please use the "File description" box of the submission form to provide multiple titles and abstracts if you wish to archive multiple data tables. For more information see: https://pangaea.de/Abstract

### Cite data publications the way they can count
To increase citability and allowing the cross-link between data and journal publication, cite the data in your article publication as part of the reference list, including the DOI, e.g. as 
> "Roe, J; Doe, J R (2023): Macro and megafauna abundance during the WARM Arctic expedition in summer 2020 counted using drones. PANGAEA, https://doi.org/10.1594/PANGAEA.11100 "

## Campaign information

Please fill the template "…Campaign-table.tab" if your study was related to some kind of named campaign or expedition, and you cannot find a relevant existing entry here: https://www.pangaea.de/expeditions/ 

### Campaign mandatory fields: 

* Campaign Label
* Begin
* End
* Basis (i.e. vehicle, platform etc.)
* Responsible scientist(s)

### Campaign further documentation

Read more about campaigns here: https://wiki.pangaea.de/wiki/Campaign

## Event information

**Important note:**
==Please complete the file "…Event-table.tab" if your samplings are not related to existing events of campaign and stations listed [here!](https://www.pangaea.de/expeditions)==

The Event table gives an overview of when, where and how the samples/data were collected from the environment. We use this station list/events table to create a map of the sampling/measurement positions.

Events relate to the temporal and geospatial references of where the specimen/samples/data were collected originally.

### General event guidelines

* "Label" is a concise, unique string to unambiguously identify the event (e.g. a combination of date, location and/or sample number)
* Latitude/longitude must be given in decimal degree (S and W are negative!) and **are mandatory** requirement.
* For profiles or multiple samplings at the same site, start and end of events may be defined by two date/time/lat/long/elevations in separate columns.
* Date/Time must be provided in the ISO-format (e.g. 1954-04-07T13:34:11) as coordinated universal time (UTC).
* Elevation (m) is negative below sea level.
* provide "Persistent device identifier link (e.g. registry.awi.de[^1] handle)" if available
* please delete empty/unneeded columns.


[^1]:(formerly known as the AWI device registration service sensor.awi.de) 

### Event mandatory fields: 

* Label 
* Device/Method
* DateTime 
* Latitude 
* Longitude 

### Event related further documentation

Further information on PANGAEA events can be found here: https://wiki.pangaea.de/wiki/Event

Further information on PANGAEA Geocodes (e.g. Latitude, Longitude, Elevation) can be found here: https://wiki.pangaea.de/wiki/Geocode

## Parameter information

The Parameter table "…Parameter-table.tab" summarizes all measured variables (PANGAEA parameters) that are included in the data table. It specifies units, principal investigator(s) and the methods used to generate the data.

### Parameter mandatory fields: 

* Parameter name
* Unit
* Principal investigator

### Parameter related further documentation

See the follwing wiki articles for more background on 
* [Parameter](https://wiki.pangaea.de/wiki/Parameter)
* [GEOCODE](https://wiki.pangaea.de/wiki/Geocode)
* [Principle Investigator](https://wiki.pangaea.de/wiki/Principle_investigator)
* [Method](https://wiki.pangaea.de/wiki/Method)

## Data table

The data table "…Data-table.tab" contains the numerical data ideally including a third spatial dimension geocode (e.g. "Depth, water" – for further information on PANGAEA geocodes, see https://wiki.pangaea.de/wiki/Geocode).
"Depth, water" for example is a PANGAEA geocode defining the third spatial dimension (Depth/Height) and the medium in which samples were taken. If samples were taken at surface, value = 0. If the samples were taken at a depth range, enter averages here. For other third spatial dimension geocodes (e.g. "Altitude", "Depth, soil").


### General data related guidelines
* One parameter per column.
* The column header contains the full parameter name and unit in squared brackets.
* Latitude/longitude must be given in decimal degree (S and W are negative!).
* For profiles or multiple samplings at the same site, "start" and "end" may be defined by two datetimes/lat/long/elevation columns.
* Date/Time must be provided in the ISO-format (e.g. 1954-04-07T13:34:11) as coordinated universal time (UTC). ‘Local time’ may be specified in a separate column.
* If data are missing, leave the cell empty (NOT "NA", "nd", varations of "-999999.99" or "-" etc.).
* Abbreviations should be avoided or need to be explained.

### Data related further documentation

Further information and examples can be found here: 
* https://wiki.pangaea.de/wiki/Best_practice_manuals_and_templates
* [GEOCODE](https://wiki.pangaea.de/wiki/Geocode)
